@@ -78,6 +78,8 @@ def render_input_row(
     relative_dir: Path,
     characters: Optional[str] = None,
     unicode_border: Optional[bool] = None,
+    line_numbers: bool = False,
+    code_wrap: bool = False,
 ) -> Union[Row, None]:
     """Render a Jupyter Notebook cell.
 
@@ -115,6 +117,10 @@ def render_input_row(
         unicode_border (Optional[bool]): Whether to render the cell
             borders using unicode characters. Will autodetect by
             default.
+        line_numbers (bool): Whether to render line numbers in code
+            cells. By default False.
+        code_wrap (bool): Whether to wrap code if it does not fit. By
+            default False.
 
     Returns:
         Row: The execution count indicator and cell content if cell type
@@ -153,6 +159,8 @@ def render_input_row(
             safe_box=safe_box,
             theme=theme,
             default_lexer_name=default_lexer_name,
+            line_numbers=line_numbers,
+            code_wrap=code_wrap,
         )
 
     elif cell_type == "raw":
